==> inventive-inventory-1.3.2-sources.jar: net/inventive_mods/inventive_inventory/util/widgets/TabbedScreen.java <==
package net.inventive_mods.inventive_inventory.util.widgets;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_7842;

public abstract class TabbedScreen extends class_437 {
    private final class_437 parent;
    protected static ScreenTab activeTab;
    protected final List<ScreenTab> tabs = new ArrayList<>();
    protected final TabbedThreePartsLayoutWidget layout = new TabbedThreePartsLayoutWidget(this, 50, 33);

    public TabbedScreen(class_437 parent, String titleTranslationKey) {
        super(class_2561.method_43471(titleTranslationKey));
        this.parent = parent;
    }

    @Override
    protected void method_25426() {
        this.initHeader();
        this.addTabs();
        this.initBody();
        this.initFooter();
        this.layout.method_48206(this::method_37063);
        this.method_48640();
    }

    protected void initHeader() {
        this.layout.method_48993(new class_7842(this.field_22785, this.field_22793), positioner -> positioner.method_46468(0.25f));
    }

    protected void addTabs() {

    }

    protected void initBody() {
        activeTab = this.layout.method_48999(this.tabs.get(0));
    }

    protected void initFooter() {
        this.layout.method_48996(class_4185.method_46430(class_5244.field_24334, button -> this.method_25419()).method_46432(200).method_46431());
    }

    protected void method_48640() {
        this.layout.method_48222();
        this.tabs.forEach(screenTab -> screenTab.position(this.field_22789, this.layout));
    }

    @Override
    public void method_25419() {
        this.tabs.forEach(ScreenTab::onClose);
        if (this.field_22787 != null) this.field_22787.method_1507(this.parent);
    }

    protected void addTab(String translationKey, ScreenTab tab, boolean active) {
        class_4185 tabButton = class_4185.method_46430(class_2561.method_43471("config.screen.tab.inventive_inventory." + translationKey), button -> {
            this.method_37066(activeTab);
            activeTab = this.layout.replaceBody(tab);
            this.method_37063(tab);
            this.layout.toggleButtons(button);
        }).method_46431();
        tabButton.field_22763 = !active;
        this.layout.addTabButton(tabButton);
        this.tabs.add(tab);
    }
}

==> inventive-inventory-1.3.3-sources.jar: net/inventive_mods/inventive_inventory/util/widgets/TabbedScreen.java <==
package net.inventive_mods.inventive_inventory.util.widgets;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_7842;

public abstract class TabbedScreen extends class_437 {
    private final class_437 parent;
    protected static ScreenTab activeTab;
    protected final List<ScreenTab> tabs = new ArrayList<>();
    protected final TabbedThreePartsLayoutWidget layout = new TabbedThreePartsLayoutWidget(this, 50, 33);

    public TabbedScreen(class_437 parent, String titleTranslationKey) {
        super(class_2561.method_43471(titleTranslationKey));
        this.parent = parent;
    }

    @Override
    protected void method_25426() {
        this.initHeader();
        this.addTabs();
        this.initBody();
        this.initFooter();
        this.layout.method_48206(this::method_37063);
        this.method_48640();
    }

    protected void initHeader() {
        this.layout.method_48993(new class_7842(this.field_22785, this.field_22793), positioner -> positioner.method_46468(0.25f));
    }

    protected void addTabs() {

    }

    protected void initBody() {
        activeTab = this.layout.method_48999(this.tabs.getFirst());
    }

    protected void initFooter() {
        this.layout.method_48996(class_4185.method_46430(class_5244.field_24334, button -> this.method_25419()).method_46432(200).method_46431());
    }

    protected void method_48640() {
        this.layout.method_48222();
        this.tabs.forEach(screenTab -> screenTab.method_57712(this.field_22789, this.layout));
    }

    @Override
    public void method_25419() {
        this.tabs.forEach(ScreenTab::onClose);
        if (this.field_22787 != null) this.field_22787.method_1507(this.parent);
    }

    protected void addTab(String translationKey, ScreenTab tab, boolean active) {
        class_4185 tabButton = class_4185.method_46430(class_2561.method_43471("config.screen.tab.inventive_inventory." + translationKey), button -> {
            this.method_37066(activeTab);
            activeTab = this.layout.replaceBody(tab);
            this.method_37063(tab);
            this.layout.toggleButtons(button);
        }).method_46431();
        tabButton.field_22763 = !active;
        this.layout.addTabButton(tabButton);
        this.tabs.add(tab);
    }
}
